Crate psrdada_sys
source ·Structs
Constants
Statics
Functions
acct⚠
bind⚠
brk⚠
Close the dada client
Create a new DADA client main loop
Destroy a DADA client main loop
Run the DADA client read loop
Run the DADA client write loop
Close the DADA Header pluse Data Unit passive viewing mode
Connect the DADA Header plus Data Unit
Create a new DADA Header plus Data Unit
Return base addresses of data block buffers, nbufs and bufsz
Destroy a DADA Header plus Data Unit
Connect the DADA Header plus Data Unit
Return base addresses of header block buffers, nbufs and bufsz
Lock DADA Header plus Data Unit designated reader
Lock DADA Header plus Data Unit designated writer
Lock DADA Header plus Data Unit designated writer
Read the next header from the struct
Open the DADA Header plus Data Unit for passive viewing
Set the key of the DADA Header plus Data Unit
Unlock DADA Header plus Data Unit designated reader
Unlock DADA Header plus Data Unit designated writer
dup⚠
dup2⚠
feof⚠
fork⚠
getc⚠
getw⚠
Connect to an already created ipcsync_t struct in shm
Initialize an ipcbuf_t struct, creating shm and sem
Destroy the ring buffer space, semaphores, and shared memory ipcbuf_t
Disable the start-of-data flag
Disconnect from a previously connected ipcsync_t struct in shm
Enable the end-of-data flag
Enable the start-of-data flag
Test if the current buffer is the last buffer containing data
Return the size of each buffer in the ring
return CUDA device_id for the data buffer, -1 for host
Return the number of eodacks
Return the number of buffers in the ring buffer
Return the number of buffers currently flagged as clear
Get the next full buffer, and the number of bytes in it
Gets the next full buffer, but does not modify any aspect of the ring buffer
Get the next empty buffer available for writing. The
calling process must have locked “data writer” status with a call
to ipcbuf_lock_write.
Return the number of buffers currently flagged as full
Return the number of readers in
Return the number of buffersread from the ring buffer
Return the Data Block index of the read buffer
Return the current read semaphore count
Return whether reader connected, 0 == connected
Get the minimum possible buffer number that be start of data
Return the number of sodacks
Return the number of bufferswritten to the ring buffer
Reset the buffer count and end of data flags, with extreme prejudice
Return true if process is the data reader
Return true if process is the data writer
Return true if process is in writing state
Lock the shared memory into physical RAM (must be su)
Lock this process in as the data reader
Lock this process in as the data writer
Declare that the last buffer to be returned by
ipcbuf_get_next_read has been cleared and can be recycled. The
process must have locked “data reader” status with a call to
ipcbuf_lock_read
Declare that the last buffer to be returned by
ipcbuf_get_next_write has been filled with nbytes bytes. The
calling process must have locked “data writer” status with a call
to ipcbuf_lock_write. If nbytes is less than bufsz, then end of
data is implicitly set.
Initialise all buffer’s to 0’s, pageing them into RAM
Reset the buffer count and end of data flags
set the start of clocking data buffer
Return the state of the start-of-data flag
Return the read buffer byte offset from the start of the transfer
Return the write buffer byte offset from the start of the transfer
Unlock the shared memory from physical RAM (allow swap)
Unlock this process in as the data reader
Unlock this process in as the data writer
stop reading/writing to an ipcbuf
connect to an already created ipcbuf_t struct in shared memory
create a new shared memory block and initialize an ipcio_t struct
create a new shared memory block and initialize an ipcio_t struct, on GPU device_id
free all resources reserved for the ring buffer
disconnect from an already connected ipcio_t struct
get the minimum byte that may be passed to ipcio_start
return true if already open
start reading/writing to an ipcbuf
tell how many bytes can be written into the ring buffer before its full
read bytes from ipcbuf
seek into ipcbuf - valid only for reading for now
tell how many bytes can be written into the ring buffer before its full
enable start of data on the specified byte
write an end of data marker; may continue writing to ring buffer
tell the last byte written to the ring buffer
write bytes to ipcbuf
link⚠
Write a message to all listening streams
Add a listener to the multilog
Close a multilogger
Print just to a stream in the multilog format
Open a multilogger
Start another thread to receive log socket connections
nice⚠
pipe⚠
putc⚠
puts⚠
putw⚠
read⚠
recv⚠
sbrk⚠
send⚠
Useful utility
sync⚠
time⚠