Function psrdada_sys::ipcbuf_get_write_count
source · pub unsafe extern "C" fn ipcbuf_get_write_count(
arg1: *mut ipcbuf_t
) -> u64Expand description
Return the number of bufferswritten to the ring buffer
pub unsafe extern "C" fn ipcbuf_get_write_count(
arg1: *mut ipcbuf_t
) -> u64Return the number of bufferswritten to the ring buffer