#[repr(C)]
pub struct ipcbuf_t {Show 14 fields
pub state: c_int,
pub syncid: c_int,
pub semid_connect: c_int,
pub semid_data: *mut c_int,
pub shmid: *mut c_int,
pub sync: *mut ipcsync_t,
pub buffer: *mut *mut c_char,
pub shm_addr: *mut *mut c_void,
pub count: *mut c_char,
pub shmkey: *mut key_t,
pub viewbuf: u64,
pub xfer: u64,
pub soclock_buf: u64,
pub iread: c_int,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.