#[repr(C)]
pub struct ipcio_t {
pub buf: ipcbuf_t,
pub curbuf: *mut c_char,
pub curbufsz: u64,
pub bytes: u64,
pub rdwrt: c_char,
pub marked_filled: c_char,
pub sod_pending: c_char,
pub sod_buf: u64,
pub sod_byte: u64,
pub buf_ptrs: *mut *mut c_char,
pub bufs_opened: c_uint,
pub bufs_opened_max: c_uint,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.