#[repr(C)]
pub struct ipcsync_t {Show 18 fields
pub semkey_connect: key_t,
pub semkey_data: [key_t; 8],
pub nbufs: u64,
pub bufsz: u64,
pub w_buf_next: u64,
pub w_buf_curr: u64,
pub w_state: c_int,
pub w_xfer: u64,
pub r_bufs: [u64; 8],
pub r_states: [c_int; 8],
pub r_xfers: [u64; 8],
pub n_readers: c_uint,
pub s_buf: [u64; 8],
pub s_byte: [u64; 8],
pub eod: [c_char; 8],
pub e_buf: [u64; 8],
pub e_byte: [u64; 8],
pub on_device_id: c_int,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.