#[repr(C)]
pub struct multilog_t {
pub name: *mut c_char,
pub syslog: c_char,
pub logs: *mut *mut FILE,
pub nlog: c_uint,
pub mutex: pthread_mutex_t,
pub thread: pthread_t,
pub port: c_int,
pub timestamp: c_int,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.