Struct psrdada_sys::dada_client
source · #[repr(C)]pub struct dada_client {Show 18 fields
pub log: *mut multilog_t,
pub data_block: *mut ipcio_t,
pub header_block: *mut ipcbuf_t,
pub open_function: Option<unsafe extern "C" fn(arg1: *mut dada_client) -> c_int>,
pub io_function: Option<unsafe extern "C" fn(arg1: *mut dada_client, data: *mut c_void, data_size: u64) -> i64>,
pub io_block_function: Option<unsafe extern "C" fn(arg1: *mut dada_client, data: *mut c_void, data_size: u64, block_id: u64) -> i64>,
pub io_block_function_cuda: Option<unsafe extern "C" fn(arg1: *mut dada_client, data: *mut c_void, data_size: u64, block_id: u64) -> i64>,
pub close_function: Option<unsafe extern "C" fn(arg1: *mut dada_client, bytes_written: u64) -> c_int>,
pub context: *mut c_void,
pub header: *mut c_char,
pub header_size: u64,
pub header_transfer: c_char,
pub direction: c_char,
pub fd: c_int,
pub transfer_bytes: u64,
pub optimal_bytes: u64,
pub quit: c_char,
pub quiet: c_int,
}Fields
log: *mut multilog_tThe status and error logging interface
data_block: *mut ipcio_tThe Data Block interface
header_block: *mut ipcbuf_tThe Header Block interface
open_function: Option<unsafe extern "C" fn(arg1: *mut dada_client) -> c_int>Pointer to the function that opens the data transfer target
io_function: Option<unsafe extern "C" fn(arg1: *mut dada_client, data: *mut c_void, data_size: u64) -> i64>Pointer to the function that transfers data to/from the target
io_block_function: Option<unsafe extern "C" fn(arg1: *mut dada_client, data: *mut c_void, data_size: u64, block_id: u64) -> i64>Pointer to the function that directly operates on shared memory blocks
io_block_function_cuda: Option<unsafe extern "C" fn(arg1: *mut dada_client, data: *mut c_void, data_size: u64, block_id: u64) -> i64>Pointer to the function that directly operations on device memory
close_function: Option<unsafe extern "C" fn(arg1: *mut dada_client, bytes_written: u64) -> c_int>Pointer to the function that closes the data transfer target
context: *mut c_voidAdditional context information
header: *mut c_charheader_size: u64header_transfer: c_chardirection: c_charfd: c_intThe file descriptor of the data transfer target
transfer_bytes: u64The total number of bytes to be transfered to/from the target
optimal_bytes: u64The optimal number of bytes to transfer to/from the target buffer
quit: c_charThe quit flag
quiet: c_intThe quiet flag